"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TaskServiceComponent = void 0;
const tslib_1 = require("tslib");
// Copyright (c) 2023 Sourcefuse Technologies
//
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT
const core_1 = require("@loopback/core");
const rest_1 = require("@loopback/rest");
const bpmn_service_1 = require("@sourceloop/bpmn-service");
const core_2 = require("@sourceloop/core");
const loopback4_authentication_1 = require("loopback4-authentication");
const loopback4_authorization_1 = require("loopback4-authorization");
const controllers = tslib_1.__importStar(require("./controllers"));
const keys_1 = require("./keys");
const lifecycle_observers_1 = require("./lifecycle-observers");
const models_1 = require("./models");
const providers_1 = require("./providers");
const system_user_provider_1 = require("./providers/system-user.provider");
const repositories_1 = require("./repositories");
const sequelize_1 = require("./repositories/sequelize");
const services_1 = require("./services");
const sequelize_2 = require("@sourceloop/bpmn-service/sequelize");
let TaskServiceComponent = class TaskServiceComponent {
    constructor(application, config) {
        var _a;
        this.application = application;
        this.config = config;
        this.providers = {};
        this.bindings = [];
        this.application.component(core_2.CoreComponent);
        this.application.api({
            openapi: '3.0.0',
            info: {
                title: 'Task Service',
                version: '1.0.0',
            },
            paths: {},
            components: {
                securitySchemes: core_2.SECURITY_SCHEME_SPEC,
            },
            servers: [{ url: '/' }],
        });
        this.application.component(bpmn_service_1.WorkflowServiceComponent);
        this.controllers = [
            controllers.EventController,
            controllers.TaskController,
            controllers.TaskUserTaskController,
        ];
        if (config === null || config === void 0 ? void 0 : config.useSequelize) {
            this.repositories = [
                sequelize_1.EventRepository,
                sequelize_1.TaskRepository,
                sequelize_1.EventWorkflowRepository,
                sequelize_1.TaskWorkFlowRepository,
                sequelize_1.UserTaskRepository,
                sequelize_2.WorkflowRepository,
                sequelize_2.WorkflowVersionRepository,
            ];
        }
        else {
            this.repositories = [
                repositories_1.EventRepository,
                repositories_1.TaskRepository,
                repositories_1.EventWorkflowRepository,
                repositories_1.TaskWorkFlowRepository,
                repositories_1.UserTaskRepository,
                bpmn_service_1.WorkflowRepository,
                bpmn_service_1.WorkflowVersionRepository,
            ];
        }
        this.providers = {
            [keys_1.TaskServiceBindings.SYSTEM_USER.key]: system_user_provider_1.SystemUserProvider,
            [bpmn_service_1.WorkflowServiceBindings.WorkflowManager.key]: providers_1.BpmnProvider,
        };
        this.models = [models_1.EventWorkflow, models_1.Event, models_1.TaskWorkflow, models_1.Task, models_1.UserTask];
        this.services = [services_1.CamundaService, services_1.UtilityService, services_1.HttpClientService];
        this.bindings = [
            (0, core_1.createBindingFromClass)(services_1.EventProcessorService, {
                key: keys_1.TaskServiceBindings.EVENT_PROCESSOR,
            }),
            (0, core_1.createBindingFromClass)(services_1.UserTaskService, {
                key: keys_1.TaskServiceBindings.SUB_TASK_SERVICE,
            }),
        ];
        if (!((_a = this.config) === null || _a === void 0 ? void 0 : _a.useCustomSequence)) {
            this.setupSequence();
        }
        // default filter does not skip any events
        this.application.bind(keys_1.TaskServiceBindings.EVENT_FILTER).to(() => true);
        this.application.lifeCycleObserver(lifecycle_observers_1.EventStreamObserver);
        this.application.lifeCycleObserver(lifecycle_observers_1.CommandObserver);
    }
    /**
     * Setup ServiceSequence by default if no other sequnce provided
     */
    setupSequence() {
        this.application.component(loopback4_authentication_1.AuthenticationComponent);
        this.application.component(loopback4_authorization_1.AuthorizationComponent);
        this.application.sequence(core_2.ServiceSequence);
    }
};
exports.TaskServiceComponent = TaskServiceComponent;
exports.TaskServiceComponent = TaskServiceComponent = tslib_1.__decorate([
    tslib_1.__param(0, (0, core_1.inject)(core_1.CoreBindings.APPLICATION_INSTANCE)),
    tslib_1.__param(1, (0, core_1.inject)(keys_1.TaskServiceBindings.CONFIG, { optional: true })),
    tslib_1.__metadata("design:paramtypes", [rest_1.RestApplication, Object])
], TaskServiceComponent);
//# sourceMappingURL=component.js.map