"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SqsStreamService = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@loopback/core");
const rest_1 = require("@loopback/rest");
const core_2 = require("@sourceloop/core");
const aws_sdk_1 = require("aws-sdk");
const keys_1 = require("./keys");
let SqsStreamService = class SqsStreamService {
    constructor(settings, adapter, logger) {
        this.settings = settings;
        this.adapter = adapter;
        this.logger = logger;
    }
    async subscribe(handler) {
        this.connection = new aws_sdk_1.SQS({
            region: this.settings.region,
            accessKeyId: this.settings.accessKeyId,
            secretAccessKey: this.settings.secretAccessKey,
        });
        const queueUrl = this.settings.queueUrl;
        const receiveParams = {
            QueueUrl: queueUrl,
            MaxNumberOfMessages: 10,
            WaitTimeSeconds: 20,
        };
        const receiveMessages = async () => {
            var _a;
            if (!this.connection)
                return;
            try {
                const data = await ((_a = this.connection) === null || _a === void 0 ? void 0 : _a.receiveMessage(receiveParams).promise());
                const messages = data.Messages;
                if (messages === null || messages === void 0 ? void 0 : messages.length) {
                    const messagePromises = messages.map(async (message) => {
                        var _a;
                        await this.adapter.adaptTo(message).then(msg => handler(msg));
                        await ((_a = this.connection) === null || _a === void 0 ? void 0 : _a.deleteMessage({
                            QueueUrl: queueUrl,
                            ReceiptHandle: message.ReceiptHandle,
                        }).promise());
                    });
                    await Promise.all(messagePromises);
                }
            }
            catch (error) {
                throw new rest_1.HttpErrors.InternalServerError(`Error with Queue, ${error}`);
            }
            // eslint-disable-next-line @typescript-eslint/no-floating-promises
            receiveMessages();
        };
        // eslint-disable-next-line @typescript-eslint/no-floating-promises
        receiveMessages();
    }
    async unsubscribe() {
        this.connection = undefined;
    }
    async publish(message) {
        if (!this.connection) {
            this.logger.error('Output connection not found for sqs connector');
            return;
        }
        const adapted = await this.adapter.adaptFrom(message);
        const params = {
            MessageBody: JSON.stringify(adapted),
            QueueUrl: this.settings.queueUrl,
        };
        await this.connection.sendMessage(params).promise();
    }
};
exports.SqsStreamService = SqsStreamService;
exports.SqsStreamService = SqsStreamService = tslib_1.__decorate([
    tslib_1.__param(0, (0, core_1.inject)(keys_1.TaskServiceSQSModule.CONFIG)),
    tslib_1.__param(1, (0, core_1.inject)(keys_1.TaskServiceSQSModule.ADAPTER)),
    tslib_1.__param(2, (0, core_1.inject)(core_2.LOGGER.LOGGER_INJECT)),
    tslib_1.__metadata("design:paramtypes", [Object, Object, Object])
], SqsStreamService);
//# sourceMappingURL=sqs-stream.service.js.map