"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TaskUserTaskController = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@loopback/core");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const core_2 = require("@sourceloop/core");
const loopback4_authentication_1 = require("loopback4-authentication");
const loopback4_authorization_1 = require("loopback4-authorization");
const keys_1 = require("../keys");
const models_1 = require("../models");
const repositories_1 = require("../repositories");
const baseUrl = 'tasks/{taskId}/user-tasks';
let TaskUserTaskController = class TaskUserTaskController {
    constructor(userTaskService, taskRepo, userTaskRepo) {
        this.userTaskService = userTaskService;
        this.taskRepo = taskRepo;
        this.userTaskRepo = userTaskRepo;
    }
    async completeTask(id, userTaskId) {
        // need to maintain and validate mapping of task and user task
        await this.userTaskService.complete(id, userTaskId);
    }
    async find(taskId, filter) {
        return this.taskRepo.userTasks(taskId).find(filter);
    }
    async findById(taskId, userTaskId, filter) {
        const userTask = await this.taskRepo.userTasks(taskId).find({
            where: {
                id: userTaskId,
            },
            ...filter,
        });
        if (!userTask.length) {
            throw new rest_1.HttpErrors.NotFound('User Task not found');
        }
        return userTask[0];
    }
    async count(taskId, where) {
        const whereBuilder = new repository_1.WhereBuilder();
        whereBuilder.and({ taskId }).and({ ...where });
        return this.userTaskRepo.count(whereBuilder.build());
    }
    async deleteById(id) {
        await this.userTaskRepo.deleteByIdHard(id);
    }
    async delete(where) {
        await this.userTaskRepo.deleteAllHard(where);
    }
};
exports.TaskUserTaskController = TaskUserTaskController;
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: ["16005" /* TaskPermssionKey.CompleteUserTask */] }),
    (0, rest_1.patch)(`${baseUrl}/{userTaskId}/complete`, {
        security: core_2.OPERATION_SECURITY_SPEC,
        responses: {},
    }),
    tslib_1.__param(0, rest_1.param.path.string('taskId')),
    tslib_1.__param(1, rest_1.param.path.string('userTaskId')),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, String]),
    tslib_1.__metadata("design:returntype", Promise)
], TaskUserTaskController.prototype, "completeTask", null);
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */),
    (0, loopback4_authorization_1.authorize)({
        permissions: ["16004" /* TaskPermssionKey.ViewUserTask */],
    }),
    (0, rest_1.get)(baseUrl, {
        security: core_2.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'Array of UserTask model instances',
                content: {
                    [core_2.CONTENT_TYPE.JSON]: {
                        schema: {
                            type: 'array',
                            items: (0, rest_1.getModelSchemaRef)(models_1.UserTask, { includeRelations: true }),
                        },
                    },
                },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.path.string('taskId')),
    tslib_1.__param(1, rest_1.param.filter(models_1.UserTask)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], TaskUserTaskController.prototype, "find", null);
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */),
    (0, loopback4_authorization_1.authorize)({
        permissions: ["16004" /* TaskPermssionKey.ViewUserTask */],
    }),
    (0, rest_1.get)(`${baseUrl}/{userTaskId}`, {
        security: core_2.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'UserTask model instance',
                content: {
                    [core_2.CONTENT_TYPE.JSON]: {
                        schema: (0, rest_1.getModelSchemaRef)(models_1.UserTask, { includeRelations: true }),
                    },
                },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.path.string('taskId')),
    tslib_1.__param(1, rest_1.param.path.string('userTaskId')),
    tslib_1.__param(2, rest_1.param.filter(models_1.UserTask, { exclude: 'where' })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, String, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], TaskUserTaskController.prototype, "findById", null);
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */),
    (0, loopback4_authorization_1.authorize)({
        permissions: ["16004" /* TaskPermssionKey.ViewUserTask */],
    }),
    (0, rest_1.get)(`${baseUrl}/count`, {
        security: core_2.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'Task model count',
                content: { [core_2.CONTENT_TYPE.JSON]: { schema: repository_1.CountSchema } },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.path.string('taskId')),
    tslib_1.__param(1, rest_1.param.where(models_1.UserTask)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], TaskUserTaskController.prototype, "count", null);
tslib_1.__decorate([
    (0, loopback4_authorization_1.authorize)({
        permissions: ["16009" /* TaskPermssionKey.DeleteUserTask */],
    }),
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */, {
        passReqToCallback: true,
    }),
    (0, rest_1.del)(`${baseUrl}/{id}`, {
        security: core_2.OPERATION_SECURITY_SPEC,
        responses: {
            [204 /* STATUS_CODE.NO_CONTENT */]: {
                description: 'UserTasks DELETE by id success',
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.path.string('id')),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String]),
    tslib_1.__metadata("design:returntype", Promise)
], TaskUserTaskController.prototype, "deleteById", null);
tslib_1.__decorate([
    (0, loopback4_authorization_1.authorize)({
        permissions: ["16009" /* TaskPermssionKey.DeleteUserTask */],
    }),
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */, {
        passReqToCallback: true,
    }),
    (0, rest_1.del)(`${baseUrl}`, {
        security: core_2.OPERATION_SECURITY_SPEC,
        responses: {
            [204 /* STATUS_CODE.NO_CONTENT */]: {
                description: 'UserTasks DELETE success',
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.where(models_1.UserTask)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object]),
    tslib_1.__metadata("design:returntype", Promise)
], TaskUserTaskController.prototype, "delete", null);
exports.TaskUserTaskController = TaskUserTaskController = tslib_1.__decorate([
    tslib_1.__param(0, (0, core_1.inject)(keys_1.TaskServiceBindings.SUB_TASK_SERVICE)),
    tslib_1.__param(1, (0, repository_1.repository)(repositories_1.TaskRepository)),
    tslib_1.__param(2, (0, repository_1.repository)(repositories_1.UserTaskRepository)),
    tslib_1.__metadata("design:paramtypes", [Object, repositories_1.TaskRepository,
        repositories_1.UserTaskRepository])
], TaskUserTaskController);
//# sourceMappingURL=task-user-task.controller.js.map